@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package JSON::Schema::Modern::Document::OpenAPI; # git description: v0.003-24-g17adc07
+package JSON::Schema::Modern::Document::OpenAPI; # git description: v0.004-6-ge19d9f1
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One OpenAPI v3.1 document
 # KEYWORDS: JSON Schema data validation request response OpenAPI
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -15,13 +15,15 @@ use if "$]" >= 5.022, experimental => 're_strict';
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
-use JSON::Schema::Modern::Utilities 0.525 qw(assert_keyword_exists assert_keyword_type E get_type canonical_uri);
+use JSON::Schema::Modern::Utilities 0.525 qw(assert_keyword_exists assert_keyword_type E canonical_uri);
 use Safe::Isa;
 use File::ShareDir 'dist_dir';
 use Path::Tiny;
 use List::Util 'any';
+use Ref::Util 'is_plain_hashref';
+use MooX::HandlesVia;
 use MooX::TypeTiny 0.002002;
-use Types::Standard 'InstanceOf';
+use Types::Standard qw(InstanceOf HashRef Str);
 use namespace::clean;
 
 extends 'JSON::Schema::Modern::Document';
@@ -52,6 +54,19 @@ has json_schema_dialect => (
   coerce => sub { $_[0]->$_isa('Mojo::URL') ? $_[0] : Mojo::URL->new($_[0]) },
 );
 
+# operationId => document path
+has operationIds => (
+  is => 'bare',
+  isa => HashRef[Str],
+   handles_via => 'Hash',
+   handles => {
+     _add_operationId => 'set',
+     get_operationId => 'get',
+  },
+  lazy => 1,
+  default => sub { {} },
+);
+
 sub traverse ($self, $evaluator) {
   $self->_add_vocab_and_default_schemas;
 
@@ -105,17 +120,21 @@ sub traverse ($self, $evaluator) {
     $self->_set_json_schema_dialect($json_schema_dialect);
   }
 
-  # evaluate the document against its metaschema to find any errors, and to identify all schema
-  # resources within to add to the global resource index.
-  my @json_schema_paths;
+  # evaluate the document against its metaschema to find any errors, to identify all schema
+  # resources within to add to the global resource index, and to extract all operationIds
+  my (@json_schema_paths, @operation_paths);
   my $result = $self->evaluator->evaluate(
     $self->schema,
     $self->metaschema_uri,
     {
       callbacks => {
-        '$dynamicRef' => sub ($schema, $state) {
+        '$dynamicRef' => sub ($, $schema, $state) {
           push @json_schema_paths, $state->{data_path} if $schema->{'$dynamicRef'} eq '#meta';
         },
+        '$ref' => sub ($data, $schema, $state) {
+          push @operation_paths, [ $data->{operationId} => $state->{data_path} ]
+            if $schema->{'$ref'} eq '#/$defs/operation' and defined $data->{operationId};
+        },
       },
     },
   );
@@ -128,12 +147,23 @@ sub traverse ($self, $evaluator) {
   my @real_json_schema_paths;
   foreach my $path (sort @json_schema_paths) {
     # disregard paths that are not the root of each embedded subschema.
-    next if any { $_->subsumes($path) } @real_json_schema_paths;
+    next if any { return $path =~ m{^\Q$_\E(?:/|\z)} } @real_json_schema_paths;
 
-    push @real_json_schema_paths, path($path);
+    unshift @real_json_schema_paths, $path;
     $self->_traverse_schema($self->get($path), { %$state, schema_path => $path });
   }
 
+  foreach my $pair (@operation_paths) {
+    my ($operation_id, $path) = @$pair;
+    if (my $existing = $self->get_operationId($operation_id)) {
+      ()= E({ %$state, keyword => 'operationId', schema_path => $path },
+        'duplicate operationId (with location %s)', $existing);
+    }
+    else {
+      $self->_add_operationId($operation_id => $path);
+    }
+  }
+
   return $state;
 }
 
@@ -154,8 +184,7 @@ sub _add_vocab_and_default_schemas ($self) {
 
 # https://spec.openapis.org/oas/v3.1.0#schema-object
 sub _traverse_schema ($self, $schema, $state) {
-  my $schema_type = get_type($schema);
-  return 1 if $schema_type eq 'boolean' or $schema_type eq 'object' and not keys %$schema;
+  return if not is_plain_hashref($schema) or not keys %$schema;
 
   my $subschema_state = $self->evaluator->traverse($schema, {
     %$state,  # so we don't have to ennumerate everything that may be in config_override
@@ -184,7 +213,7 @@ JSON::Schema::Modern::Document::OpenAPI - One OpenAPI v3.1 document
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -246,6 +275,13 @@ not a JSON Schema). Note that you may need to explicitly set that attribute as w
 C<json_schema_dialect>, as the default metaschema used by the default C<metaschema_uri> can no
 longer be assumed.
 
+=head1 METHODS
+
+=head2 get_operationId
+
+Returns the json pointer location of the operation containing the provided C<operationId> (suitable
+for passing to C<< $document->get(..) >>), or C<undef> if it is not contained in the document.
+
 =head1 SUPPORT
 
 Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Modern-Document-OpenAPI/issues>.
