@@ -5,7 +5,7 @@ package OpenAPI::Modern;
 # ABSTRACT: Validate HTTP requests and responses against an OpenAPI document
 # KEYWORDS: validation evaluation JSON Schema OpenAPI Swagger HTTP request response
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use 5.020;  # for fc, unicode_strings features
 use Moo;
@@ -415,7 +415,7 @@ OpenAPI::Modern - Validate HTTP requests and responses against an OpenAPI docume
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -499,7 +499,8 @@ prints:
 
 =head1 DESCRIPTION
 
-This module provides various tools for working with an OpenAPI Specification v3.1 document within
+This module provides various tools for working with an
+L<OpenAPI Specification v3.1 document|https://spec.openapis.org/oas/v3.1.0#openapi-document> within
 your application. The JSON Schema evaluator is fully specification-compliant; the OpenAPI evaluator
 aims to be but some features are not yet available. My belief is that missing features are better
 than features that seem to work but actually cut corners for simplicity.
@@ -510,12 +511,6 @@ than features that seem to work but actually cut corners for simplicity.
 
 =head1 CONSTRUCTOR ARGUMENTS
 
-=head2 openapi_document
-
-The L<JSON::Schema::Modern::Document::OpenAPI> document that holds the OpenAPI information to be
-used for validation. If it is not provided to the constructor, then L</openapi_uri> and
-L</openapi_schema> B<MUST> be provided, and L</evaluator> will also be used if provided.
-
 =head2 openapi_uri
 
 The URI that identifies the OpenAPI document.
@@ -526,17 +521,18 @@ Ignored if L</openapi_document> is provided.
 The data structure describing the OpenAPI v3.1 document (as specified at
 L<https://spec.openapis.org/oas/v3.1.0>). Ignored if L</openapi_document> is provided.
 
-=head2 evaluator
-
-The L<JSON::Schema::Modern> object to use for all URI resolution and JSON Schema evaluation.
-Ignored if L</openapi_document> is provided.
-
-=head1 ACCESSORS
-
 =head2 openapi_document
 
 The L<JSON::Schema::Modern::Document::OpenAPI> document that holds the OpenAPI information to be
-used for validation.
+used for validation. If it is not provided to the constructor, then L</openapi_uri> and
+L</openapi_schema> B<MUST> be provided, and L</evaluator> will also be used if provided.
+
+=head2 evaluator
+
+The L<JSON::Schema::Modern> object to use for all URI resolution and JSON Schema evaluation.
+Ignored if L</openapi_document> is provided. Optional.
+
+=head1 ACCESSORS/METHODS
 
 =head2 openapi_uri
 
@@ -546,12 +542,15 @@ The URI that identifies the OpenAPI document.
 
 The data structure describing the OpenAPI document. See L<the specification/https://spec.openapis.org/oas/v3.1.0>.
 
+=head2 openapi_document
+
+The L<JSON::Schema::Modern::Document::OpenAPI> document that holds the OpenAPI information to be
+used for validation.
+
 =head2 evaluator
 
 The L<JSON::Schema::Modern> object to use for all URI resolution and JSON Schema evaluation.
 
-=head1 METHODS
-
 =head2 validate_request
 
   $result = $openapi->validate_request(
@@ -562,7 +561,7 @@ The L<JSON::Schema::Modern> object to use for all URI resolution and JSON Schema
     },
   );
 
-Validates an L<HTTP::Request> object against the corresponding OpenAPI v3.1 specification, returning a
+Validates an L<HTTP::Request> object against the corresponding OpenAPI v3.1 document, returning a
 L<JSON::Schema::Modern::Result> object.
 
 The second argument is a hashref that contains extra information about the request. Possible values include:
@@ -579,6 +578,8 @@ C<path_captures>: a hashref mapping placeholders in the path to their actual val
 
 =back
 
+More options will be added later, providing more flexible matching of the document to the request.
+
 =head2 validate_response
 
   $result = $openapi->validate_response(
@@ -598,6 +599,8 @@ C<path_template>: a string representing the request URI, with placeholders in br
 
 =back
 
+More options will be added later, providing more flexible matching of the document to the request.
+
 =head1 ON THE USE OF JSON SCHEMAS
 
 Embedded JSON Schemas, through the use of the C<schema> keyword, are fully draft2020-12-compliant,
@@ -625,7 +628,7 @@ therefore inadvertently contain perlish numbers rather than strings.
 
 =head1 LIMITATIONS
 
-Only certain permutations of OpenAPI specifications and are supported at this time:
+Only certain permutations of OpenAPI documents are supported at this time:
 
 =over 4
 
